@@ -52,10 +52,7 @@ class TestHashContext(object):
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestSHA1(object):
-    test_SHA1 = generate_base_hash_test(
-        hashes.SHA1(),
-        digest_size=20,
-    )
+    test_sha1 = generate_base_hash_test(hashes.SHA1(), digest_size=20,)
 
 
 @pytest.mark.supported(
@@ -64,10 +61,7 @@ class TestSHA1(object):
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestSHA224(object):
-    test_SHA224 = generate_base_hash_test(
-        hashes.SHA224(),
-        digest_size=28,
-    )
+    test_sha224 = generate_base_hash_test(hashes.SHA224(), digest_size=28,)
 
 
 @pytest.mark.supported(
@@ -76,10 +70,7 @@ class TestSHA224(object):
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestSHA256(object):
-    test_SHA256 = generate_base_hash_test(
-        hashes.SHA256(),
-        digest_size=32,
-    )
+    test_sha256 = generate_base_hash_test(hashes.SHA256(), digest_size=32,)
 
 
 @pytest.mark.supported(
@@ -88,10 +79,7 @@ class TestSHA256(object):
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestSHA384(object):
-    test_SHA384 = generate_base_hash_test(
-        hashes.SHA384(),
-        digest_size=48,
-    )
+    test_sha384 = generate_base_hash_test(hashes.SHA384(), digest_size=48,)
 
 
 @pytest.mark.supported(
@@ -100,10 +88,7 @@ class TestSHA384(object):
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestSHA512(object):
-    test_SHA512 = generate_base_hash_test(
-        hashes.SHA512(),
-        digest_size=64,
-    )
+    test_sha512 = generate_base_hash_test(hashes.SHA512(), digest_size=64,)
 
 
 @pytest.mark.supported(
@@ -112,22 +97,19 @@ class TestSHA512(object):
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestMD5(object):
-    test_MD5 = generate_base_hash_test(
-        hashes.MD5(),
-        digest_size=16,
-    )
+    test_md5 = generate_base_hash_test(hashes.MD5(), digest_size=16,)
 
 
 @pytest.mark.supported(
     only_if=lambda backend: backend.hash_supported(
-        hashes.BLAKE2b(digest_size=64)),
+        hashes.BLAKE2b(digest_size=64)
+    ),
     skip_message="Does not support BLAKE2b",
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestBLAKE2b(object):
-    test_BLAKE2b = generate_base_hash_test(
-        hashes.BLAKE2b(digest_size=64),
-        digest_size=64,
+    test_blake2b = generate_base_hash_test(
+        hashes.BLAKE2b(digest_size=64), digest_size=64,
     )
 
     def test_invalid_digest_size(self, backend):
@@ -143,14 +125,14 @@ class TestBLAKE2b(object):
 
 @pytest.mark.supported(
     only_if=lambda backend: backend.hash_supported(
-        hashes.BLAKE2s(digest_size=32)),
+        hashes.BLAKE2s(digest_size=32)
+    ),
     skip_message="Does not support BLAKE2s",
 )
 @pytest.mark.requires_backend_interface(interface=HashBackend)
 class TestBLAKE2s(object):
-    test_BLAKE2s = generate_base_hash_test(
-        hashes.BLAKE2s(digest_size=32),
-        digest_size=32,
+    test_blake2s = generate_base_hash_test(
+        hashes.BLAKE2s(digest_size=32), digest_size=32,
     )
 
     def test_invalid_digest_size(self, backend):
@@ -182,18 +164,12 @@ def test_buffer_protocol_hash(backend):
 
 
 class TestSHAKE(object):
-    @pytest.mark.parametrize(
-        "xof",
-        [hashes.SHAKE128, hashes.SHAKE256]
-    )
+    @pytest.mark.parametrize("xof", [hashes.SHAKE128, hashes.SHAKE256])
     def test_invalid_digest_type(self, xof):
         with pytest.raises(TypeError):
             xof(digest_size=object())
 
-    @pytest.mark.parametrize(
-        "xof",
-        [hashes.SHAKE128, hashes.SHAKE256]
-    )
+    @pytest.mark.parametrize("xof", [hashes.SHAKE128, hashes.SHAKE256])
     def test_invalid_digest_size(self, xof):
         with pytest.raises(ValueError):
             xof(digest_size=-5)
